@@ -1,5 +1,5 @@
-from exceptions import NoInputError, NoPlayerFoundError
-from hypixelaPY import hypixel
+from .exceptions import NoInputError, NoPlayerFoundError
+import hypixel
 import mojang
 
 
